@@ -17,11 +17,13 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#error "Only <gtk/gtk.h> can be included directly."
+#endif
+
 #ifndef __GTK_CELL_RENDERER_H__
 #define __GTK_CELL_RENDERER_H__
 
-#include <gtk/gtkobject.h>
-#include <gtk/gtkwidget.h>
 #include <gtk/gtkcelleditable.h>
 
 G_BEGIN_DECLS
@@ -57,20 +59,22 @@ struct _GtkCellRenderer
 {
   GtkObject parent;
 
-  gfloat xalign;
-  gfloat yalign;
+  gfloat GSEAL (xalign);
+  gfloat GSEAL (yalign);
 
-  gint width;
-  gint height;
+  gint GSEAL (width);
+  gint GSEAL (height);
 
-  guint16 xpad;
-  guint16 ypad;
+  guint16 GSEAL (xpad);
+  guint16 GSEAL (ypad);
 
-  guint mode : 2;
-  guint visible : 1;
-  guint is_expander : 1;
-  guint is_expanded : 1;
-  guint cell_background_set : 1;
+  guint GSEAL (mode) : 2;
+  guint GSEAL (visible) : 1;
+  guint GSEAL (is_expander) : 1;
+  guint GSEAL (is_expanded) : 1;
+  guint GSEAL (cell_background_set) : 1;
+  guint GSEAL (sensitive) : 1;
+  guint GSEAL (editing) : 1;
 };
 
 struct _GtkCellRendererClass
@@ -86,7 +90,7 @@ struct _GtkCellRendererClass
 				      gint                 *width,
 				      gint                 *height);
   void             (* render)        (GtkCellRenderer      *cell,
-				      GdkWindow            *window,
+				      GdkDrawable          *window,
 				      GtkWidget            *widget,
 				      GdkRectangle         *background_area,
 				      GdkRectangle         *cell_area,
@@ -107,18 +111,22 @@ struct _GtkCellRendererClass
 				      GdkRectangle         *cell_area,
 				      GtkCellRendererState  flags);
 
+  /* Signals */
+  void (* editing_canceled) (GtkCellRenderer *cell);
+  void (* editing_started)  (GtkCellRenderer *cell,
+			     GtkCellEditable *editable,
+			     const gchar     *path);
+
   /* Padding for future expansion */
   void (*_gtk_reserved1) (void);
   void (*_gtk_reserved2) (void);
-  void (*_gtk_reserved3) (void);
-  void (*_gtk_reserved4) (void);
 };
 
 GType            gtk_cell_renderer_get_type       (void) G_GNUC_CONST;
 
 void             gtk_cell_renderer_get_size       (GtkCellRenderer      *cell,
 						   GtkWidget            *widget,
-						   GdkRectangle         *cell_area,
+						   const GdkRectangle   *cell_area,
 						   gint                 *x_offset,
 						   gint                 *y_offset,
 						   gint                 *width,
@@ -126,23 +134,23 @@ void             gtk_cell_renderer_get_size       (GtkCellRenderer      *cell,
 void             gtk_cell_renderer_render         (GtkCellRenderer      *cell,
 						   GdkWindow            *window,
 						   GtkWidget            *widget,
-						   GdkRectangle         *background_area,
-						   GdkRectangle         *cell_area,
-						   GdkRectangle         *expose_area,
+						   const GdkRectangle   *background_area,
+						   const GdkRectangle   *cell_area,
+						   const GdkRectangle   *expose_area,
 						   GtkCellRendererState  flags);
 gboolean         gtk_cell_renderer_activate       (GtkCellRenderer      *cell,
 						   GdkEvent             *event,
 						   GtkWidget            *widget,
 						   const gchar          *path,
-						   GdkRectangle         *background_area,
-						   GdkRectangle         *cell_area,
+						   const GdkRectangle   *background_area,
+						   const GdkRectangle   *cell_area,
 						   GtkCellRendererState  flags);
 GtkCellEditable *gtk_cell_renderer_start_editing  (GtkCellRenderer      *cell,
 						   GdkEvent             *event,
 						   GtkWidget            *widget,
 						   const gchar          *path,
-						   GdkRectangle         *background_area,
-						   GdkRectangle         *cell_area,
+						   const GdkRectangle   *background_area,
+						   const GdkRectangle   *cell_area,
 						   GtkCellRendererState  flags);
 void             gtk_cell_renderer_set_fixed_size (GtkCellRenderer      *cell,
 						   gint                  width,
@@ -151,8 +159,14 @@ void             gtk_cell_renderer_get_fixed_size (GtkCellRenderer      *cell,
 						   gint                 *width,
 						   gint                 *height);
 
+/* For use by cell renderer implementations only */
+#ifndef GTK_DISABLE_DEPRECATED
+void gtk_cell_renderer_editing_canceled (GtkCellRenderer *cell);
+#endif
+void gtk_cell_renderer_stop_editing     (GtkCellRenderer *cell,
+				         gboolean         canceled);
+
 
- 
 G_END_DECLS
 
 #endif /* __GTK_CELL_RENDERER_H__ */
